timespantools.CompoundInequality
================================

.. abjad-lineage:: abjad.tools.timespantools.CompoundInequality.CompoundInequality

.. autoclass:: abjad.tools.timespantools.CompoundInequality.CompoundInequality

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.append
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.count
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.custom_identifier
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.evaluate
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.evaluate_offset_inequality
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.extend
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.get_offset_indices
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.index
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.insert
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.item_class
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.keep_sorted
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.logical_operator
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.pop
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.remove
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.reverse
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.sort
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__contains__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__delitem__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__eq__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__format__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__getitem__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__iadd__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__iter__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__len__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__makenew__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__ne__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__repr__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__reversed__
      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality.__setitem__

Bases
-----

- :py:class:`datastructuretools.TypedList <abjad.tools.datastructuretools.TypedList.TypedList>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.item_class
   :noindex:

.. autoattribute:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.logical_operator
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.custom_identifier
   :noindex:

.. autoattribute:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.keep_sorted
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.append
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.count
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.evaluate
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.evaluate_offset_inequality
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.extend
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.get_offset_indices
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.index
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.insert
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.pop
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.remove
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.reverse
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__contains__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__delitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__format__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__getitem__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__iadd__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__iter__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__len__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__makenew__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__repr__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__reversed__
   :noindex:

.. automethod:: abjad.tools.timespantools.CompoundInequality.CompoundInequality.__setitem__
   :noindex:
